==> funki-0.0.82.tar.gz: funki-0.0.82/funki/refactor_recommender.py <==
from os import listdir
from os.path import isdir

is_python_file = lambda φ: φ.endswith('.py')
remove_last_character = lambda σ: σ[:-1]
sort = lambda λ: sorted(λ, key=lambda tup: -tup[0])

class RefactorRecommender:
  def __init__(self):
    self.python_files = []
    self.lines = []
    self.ignorable = [
      '\n',
      "        )",
      "      )",
      "      ]",
      "    )",
      "    ]",
      "    except FileNotFoundError:",
      "    pass",
      "    try:",
      "  )",
      "  def __del__(self):",
      "  def __init__(self):",
      "  def run(self):",
      "  else:",
      "  except FileNotFoundError:",
      "  try:",
      "",
      ")",
      "from subprocess import run",
    ]
    self.max_line_width = 0
    self.Δ_lines = {}

  def get_list_of_python_files(self, root):
    for item in listdir(root):
      π = root+'/'+item
      if isdir(π):
        self.get_list_of_python_files(π)
      if is_python_file(item):
        self.python_files.append(π)

  def run(self):
    self.get_list_of_python_files('.')

    for python_file in self.python_files:
      with open(python_file, 'r') as φ:
        lines = φ.readlines()
        for line_index, line in enumerate(lines):
          if line[-1] == '\n':
            line = remove_last_character(line)
      
          if line not in self.ignorable:
            if line not in self.Δ_lines:
              self.Δ_lines[line] = []
        
            self.Δ_lines[line].append((python_file, line_index+1))

    refactor_recommendations = []

    for line in self.Δ_lines:
      λ = len(self.Δ_lines[line])
      if λ > 1 or len(line) > 80:
        self.max_line_width = max(self.max_line_width, len(line))
        refactor_recommendations.append((λ, self.Δ_lines[line], line))

      refactor_recommendations = sort(refactor_recommendations)

    with open('refactor.recommendations', 'w') as φ:
      for item in refactor_recommendations:
        φ.write(''.join([
          f'"{item[2]}"',
          ' '*(1+self.max_line_width-len(item[2])),
          str(item[1]),
          '\n'
        ]))

==> funki-0.0.155.tar.gz: funki-0.0.155/funki/refactor_recommender.py <==
from os import listdir
from os.path import isdir

is_python_file = lambda _file: _file.endswith('.py')
remove_last_character = lambda state: state[:-1]
sort = lambda lambdas: sorted(lambdas, key=lambda tup: -tup[0])

class RefactorRecommender:
  def __init__(self):
    self.python_files = []
    self.lines = []
    self.ignorable = [
      '\n',
      "        )",
      "      )",
      "      ]",
      "    )",
      "    ]",
      "    except FileNotFoundError:",
      "    pass",
      "    try:",
      "  )",
      "  def __del__(self):",
      "  def __init__(self):",
      "  def run(self):",
      "  else:",
      "  except FileNotFoundError:",
      "  try:",
      "",
      ")",
      "from subprocess import run",
    ]
    self.max_line_width = 0
    self.Δ_lines = {}

  def get_list_of_python_files(self, root):
    for item in listdir(root):
      π = root+'/'+item
      if isdir(π):
        self.get_list_of_python_files(π)
      if is_python_file(item):
        self.python_files.append(π)

  def run(self):
    self.get_list_of_python_files('.')

    for python_file in self.python_files:
      with open(python_file, 'r') as _file:
        print(f'python_file: {python_file}')
        for line_index, line in enumerate(_file.readlines()):
          if line[-1] == '\n':
            line = remove_last_character(line)
      
          if line not in self.ignorable:
            if line not in self.Δ_lines:
              self.Δ_lines[line] = []
        
            self.Δ_lines[line].append((python_file, line_index+1))

    refactor_recommendations = []

    for line in self.Δ_lines:
      lambdas = len(self.Δ_lines[line])
      if lambdas > 1 or len(line) > 80:
        self.max_line_width = max(self.max_line_width, len(line))
        refactor_recommendations.append((lambdas, self.Δ_lines[line], line))

      refactor_recommendations = sort(refactor_recommendations)

    with open('refactor.recommendations', 'w') as _file:
      for item in refactor_recommendations:
        _file.write(''.join([
          f'"{item[2]}"',
          ' '*(1+self.max_line_width-len(item[2])),
          str(item[1]),
          '\n'
        ]))
